function  audioPlay( DATA, SAVE_SWITCH, varargin )
%AUDIOPLAY Play a sound and save it into a file if the switch is turned on
%
%INPUT:
%DATA --- Audio wave in time domain
%SAVE_SWITCH --- The switch to determine whether to save the sound into a
%file. 'on' or 'off'. If it is 'on', the 3rd input argument is needed as a
%filename
%(FILE_NAME) --- If saving is turned on, this donates the filename for the file.
%(TIME_PERIOD) --- A two-element array determining the certain seconds of the sound
%to play; Or a number determing the starting seconds of the sound to play



[total_sec, Fs] = size(DATA);
%% Input Arguments Check
nVarargin = length( varargin );
% Saving switch
if( strcmpi(SAVE_SWITCH,'on') )
    if( nVarargin<1 )
        warning('Filename for the audio file is needed as the 3rd input argument.');
        return;
    elseif( nVarargin>2 )
        warning('Too many input arguments.');
        return;
    else
        FILE_NAME = varargin{1};
        if( ~isa(FILE_NAME, 'char') )
            warning('The 3rd input argument should be a varible of type ''char''.');
            return;
        end
        result = strfind(FILE_NAME,'.');
        if( isempty(result) )
            warning('The 3rd input argument should include a filename extension.');
            return;
        end
    end
elseif( strcmpi(SAVE_SWITCH,'off') )
    if( nVarargin>1 )
        warning('Too many input arguments.');
        return;
    end
else
    warning('The 2nd input argument should be either ''on'' or ''off''.');
    return;
end
% Time period
TIME_PERIOD = [];
if( strcmpi(SAVE_SWITCH,'on')&&nVarargin==2 )
    TIME_PERIOD = varargin{2};
elseif( strcmpi(SAVE_SWITCH,'off')&&nVarargin==1 )
    TIME_PERIOD = varargin{1};
end
if( ~isnumeric(TIME_PERIOD) )
    start_sec   = 0;
    stop_sec    = total_sec;
else
    [rows, cols] = size(TIME_PERIOD);
    if( rows*cols==1 )
        start_sec   = TIME_PERIOD(1);
        stop_sec    = total_sec;
    elseif( rows*cols==2 )
        start_sec   = TIME_PERIOD(1);
        stop_sec    = TIME_PERIOD(2);
    elseif( rows*cols==0 )
        start_sec   = 0;
        stop_sec    = total_sec;
    else
        warning('Use a two-element array to select time period of sound.');
        return;
    end
    if( start_sec>=stop_sec || stop_sec>total_sec )
        warning('No second has been selected.');
        return;
    end
    if( start_sec<0 )
        start_sec = 0;
    end
end


%% Play
audioData = zeros(1, total_sec*Fs);
for i = 1 : total_sec
    audioData(1,Fs*(i-1)+1:Fs*i) = DATA(i,:);
end
audioObj = audioplayer(audioData,Fs);
playblocking(audioObj, [start_sec*audioObj.SampleRate+1, stop_sec*audioObj.SampleRate] );


%% Save
if( strcmpi(SAVE_SWITCH,'on') )
    audiowrite(FILE_NAME, audioData(1, start_sec*audioObj.SampleRate+1 : stop_sec*audioObj.SampleRate), Fs);
end


end

