function [ status, fb ] = connInit( OS, ROLE )
%INITCONN  To make a new worker's IP recorded and give him an id 
%INPUT:
%   OS      The current operation system
%   ROLE    As a Worker or Manager
%OUTPUT:
%   status  Whether the initialization is successful; 0 means success
%   fb      For workers, it is the id of the new worker;
%           For manager, it is the list of all the worker's IPs 
load('configuration.mat');

%% For workers
if( strcmpi( ROLE, 'worker') )
    % Get local IP
    if( strcmpi( OS, 'windows') )
        [status, result] = dos('ipconfig|findstr IPv4');
        if( status ~= 0)
            disp(result);
            return;
        else
            ipAddrHeadPos = strfind(result,':');
            ipAddr = result( 1, ipAddrHeadPos+1: length(result) );
            ipAddr = strtrim(ipAddr);
        end
    elseif( strcmpi( OS, 'mac') )
        [status, result] = dos('ifconfig|grep 172.');
        if( status ~= 0)
            disp(result);
            return;
        else
            ipAddrHeadPos = strfind(result,'172.');
            ipAddrRearPos = strfind(result,'netmask');
            ipAddr = result( 1, ipAddrHeadPos+1: ipAddrRearPos-1 );
            ipAddr = strtrim(ipAddr);
        end
    end
    % Write local IP into a temporary file which will be deleted by Manager
    % get the number of workers who have already joined the group
    fb = getCurWorkerNum( conf.IP_RECORD ) + 1;
    % write new IP address into the temporary file
    fid = fopen( conf.IP_RECORD, 'a+');
    fprintf( fid, [ipAddr,'|'] );
    fclose(fid);
%% For manager
elseif ( strcmpi( ROLE, 'manager' ) )
    fid = fopen( conf.IP_RECORD, 'r');
    if( fid == -1 )
        disp([ 'Cannot open ', conf.IP_RECORD ]);
        disp('Do you run ''worker.m'' first?');
        status = -1;
        fb = 0;
        return;
    else
        records = fgetl(fid);
        temp = strsplit(records,'|');
        [~,cols] = size(temp);
        fb = temp(1,1:cols-1);
        status = 0;
    end
    fclose(fid);
    delete( conf.IP_RECORD );
end



end

