function [ ADJ_DATA ] = getAdjusted( DATA, LAG_TABLE, DOMAIN, FREQ_RESO )
%GETADJUSTED Get adjusted data by the lag table. The input data could be in
%time or frequency domain
%
%INPUT:
%DATA --- Unadjusted data
%LAG_TABLE --- A row array showing lag time. Adjustment is based on lag table. (+/- seconds)
%DOMAIN --- The domain of the input data, 'time' or 'freq'. (case insensitive)
%FREQ_RESO --- Frequency Resolution
%
%OUTPUT:
%ADJ_DATA --- Adjusted data


load('configuration.mat');
[mic_num, N] = size(DATA);
ADJ_DATA = zeros(mic_num, N);
% If data is in frequency domain
if( strcmpi(DOMAIN,'freq') )
    freq_axis = ((0:N-1)-floor(N/2))*FREQ_RESO;
    freq_axis = ifftshift(freq_axis);
    for i = 1 : mic_num
        ADJ_DATA(i,:) = DATA(i,:).*exp(2*pi*1i*freq_axis*LAG_TABLE(i)/N);
    end
    
% If data is in time domain
elseif( strcmpi(DOMAIN,'time') )
    freq_data = fft( DATA, [], 2);
    freq_axis = ((0:N-1)-floor(N/2))*FREQ_RESO;
    freq_axis = ifftshift(freq_axis);
    for i = 1 : mic_num
        freq_data(i,:) = freq_data(i,:).*exp(2*pi*1i*freq_axis*LAG_TABLE(i)/N);
        ADJ_DATA(i,:) = real( ifft(freq_data(i,:)) );
    end
%     for i = 1 : mic_num
%         if ( LAG_TABLE(i) > 0 )
%             for j = 1 + LAG_TABLE(i) : N
%                 ADJ_DATA(i, j) = DATA(i, j - LAG_TABLE(i));
%             end
%             for j = 1 : LAG_TABLE(i)
%                 ADJ_DATA(i, j) = 0;
%             end
%         else
%             for j = 1 : N + LAG_TABLE(i)
%                 ADJ_DATA(i, j) = DATA ( i, j - LAG_TABLE(i)) ;
%             end
%             for j = N + LAG_TABLE(i)+1 : N
%                 ADJ_DATA(i, j) = 0;
%             end
%         end
%     end

% Error
else
    warning('The third input argument for getAdjusted should be either ''time'' or ''freq''.');
    return;
end


end

