function [ NEW_POWER ] = getAwayNoisePower( DATA, ORIG_POWER, FREQ, SINGLE_SIDE_WIDTH, HARMONIC )
%GETAWAYNOISE Subtract the power of noise at certain frequencies from the
%original power
%
%INPUT:
%DATA --- The complete data in frequency domain after fft without
%fftshifting
%ORIG_POWER --- The total power
%FREQ --- The frequencies where the noise is
%SINGLE_SIDE_WIDTH --- The bandwidth on each side of lobes of noise
%HARMONIC --- Determine whether there are harmonic frequencies. 'on' or 'off'
%
%OUTPUT:
%NEW_POWER --- The new power



NEW_POWER = ORIG_POWER ;
[rows, cols] = size(FREQ);
freq_num = max(rows,cols);
if( strcmpi(HARMONIC,'off') )
    for i = 1 : freq_num
        NEW_POWER = NEW_POWER - 2*sum( abs(DATA(FREQ(i)+1-SINGLE_SIDE_WIDTH:FREQ(i)+1+SINGLE_SIDE_WIDTH)).^2 );
    end
elseif( strcmpi(HARMONIC,'on') )
    [~, N] = size(DATA);
    for i = 1 : freq_num
        harm_index = 1 ;
        while( FREQ(i)*harm_index<N/2 )
            NEW_POWER = NEW_POWER - 2*sum( abs(DATA(FREQ(i)*harm_index+1-SINGLE_SIDE_WIDTH:FREQ(i)*harm_index+1+SINGLE_SIDE_WIDTH)).^2 );
            harm_index = harm_index + 1;
        end
    end
end





end

