function [ status, DOA ] = getDoa( filtered_data, connState, varargin )
%GETDOA Get the DOA based on the given data independently or cooperatively
%INPUT:
%   filtered_data   The given data usually being filtered.
%   connState       '1' indicates it is a group work, meaning workers are
%                   involved; '0' indicates it is an independent work, meaning no
%                   workers involved.
%   (channel_list)  This argument is needed only when connState is 'on'.
%                   It provides a list of communication channels that are used to
%                   connect Workers to Manager.
%OUTPUT:
%   status          Whether to get the DOA successfully. (0=success, else=unsuccess)
%   DOA             The direction of arrival based on the given data.


load('configuration.mat');
%% Cooperatively (Workers are involved)
if( connState==1 )
    nVarargin = length( varargin );
    if( nVarargin~=1 )
        disp('Since network is open, the third input argument is needed.');
        status = -1;
        DOA = -1;
        return;
    end
    channel_list = varargin{1};
    if( ~isa(channel_list(1), 'tcpip') )
        disp('The third argument should be a tcpip or an array of tcpip.');
        status = -1;
        DOA = -1;
        return;
    end
    [~,worker_num] = size(channel_list);
    %Distribute
    for i = 1 : worker_num
        connSend( channel_list(i), 1, [1 1], 'integer' );     %send order
        connSend( channel_list(i), real(filtered_data), [conf.MIC_NUM, conf.BANDPASS(2)-conf.BANDPASS(1)+1], 'single' );
        connSend( channel_list(i), imag(filtered_data), [conf.MIC_NUM, conf.BANDPASS(2)-conf.BANDPASS(1)+1], 'single' );
        connSend( channel_list(i), i, [1 1], 'integer' );     %send angle_zone
    end
    % Wait for results
    rec_data = zeros( worker_num, 2 );
    for i = 1 : worker_num
        rec_data(i,:) = connReceive( channel_list(i), [1 2], 'double');
    end
    [~, max_index] = max(rec_data(:,1));
    DOA = rec_data( max_index, 2 );
    status = 0;
    
 %% Independently (No workers are involved)
elseif ( connState==0 )
    power = zeros( 1, 360/conf.RESOLUTION );
    for i = 1 :  360/conf.RESOLUTION
        [power(i)] = Beamforming(filtered_data,conf.BANDPASS,i*conf.RESOLUTION);
    end
    [~, max_index] = max(power);
    DOA = max_index*conf.RESOLUTION;
    status = 0;


%% Wrong argument
else
    disp('The second argument should be either ''1'' or ''0''.');
    status = -1;
    DOA = -1;
end




end

