% Make sure running 'worker.m' before 'manager.m'
% Each worker works as below:
% 1. Build connection to Manager
% 2. connReceive the data from Manager
% 3. Do beamforming
% 4. Return the max_angle and max_power to Manager
% 5. Wait for the order from Manager, either to go to Step 2 or to quit




%% Initialize
clc; clear all;
%A struct variable conf will be loaded that contain.
load('configuration.mat');
% windows or mac; worker or manager (both case insensitive)
[status, myId] = connInit('windows', 'worker'); 
if( status~=0 ) % if fail to initialize connection
    return;
end


%% start
%build connection to Manager as a Client in TCP/IP
%will wait until connection has been built.
tClient = connBuild( conf.MANAGER_IP, conf.PORT_LIST(myId), 'Client' );
worker_num = connReceive(tClient, [1 1], 'integer');
ZONE_SIZE = 360/worker_num;% Each worker will do such amount of degrees.
order = connReceive(tClient, [1 1], 'integer');
k=1;
while( order==1 ) %1: have data to come;  0:done
    seg_real = connReceive(tClient, [conf.MIC_NUM conf.BANDPASS(2)-conf.BANDPASS(1)+1], 'single');
    seg_imag = connReceive(tClient, [conf.MIC_NUM conf.BANDPASS(2)-conf.BANDPASS(1)+1], 'single');
    segment = seg_real + 1i*seg_imag;
    angle_zone = connReceive(tClient, [1 1], 'integer' );
    power = zeros( 1, ZONE_SIZE/conf.RESOLUTION );
    parfor i = 1 :  ZONE_SIZE/conf.RESOLUTION
        [power(i)] = Beamforming(segment,conf.BANDPASS,i*conf.RESOLUTION+ZONE_SIZE*(angle_zone-1));
    end
    [max_value, max_index] = max(power);
    max_angle = max_index*conf.RESOLUTION + ZONE_SIZE*(angle_zone-1);
    disp(max_angle);
    connSend(tClient, [max_value max_angle], [1 2], 'double' );
    order = connReceive(tClient, [1 1], 'integer');
    k = k+1;
end


%% Finish
disp('My task has been done');
connDestroy( tClient );
